@@ -1,5 +1,33 @@
 from napoleontoolbox.utility import date_utility
 import pandas as pd
+import numpy as np
+from napoleontoolbox.utility import metrics
+
+def indice_rebalancing_kpi(weight_data= None, starting_date=None, ending_date=None):
+    indice_track = weight_data['indice']
+    indice_track=indice_track.dropna()
+    if starting_date is None:
+        starting_date = min(indice_track.index)
+
+    if ending_date is None:
+        ending_date = max(indice_track.index)
+
+    starting_value = indice_track.loc[starting_date]
+    ending_value = indice_track.loc[ending_date]
+
+    days_lapse = (ending_date - starting_date).days
+
+    annualized_return = (ending_value/starting_value)**(365/(days_lapse))-1
+    vol = np.sqrt(252)*np.std(indice_track.loc[starting_date:ending_date].pct_change().fillna(0.).values)
+    annualized_return = annualized_return * 100
+    vol = vol*100
+    dd = max(metrics.drawdown(indice_track.loc[starting_date:ending_date]))*100
+    result_df = pd.DataFrame({
+        'volatility':[vol],
+        'drawdown':[dd],
+        'annualized_return':[annualized_return]
+    })
+    return result_df
 
 
 def indice_rebalancing(price_data= None, inception_date=None, target_weights=None, initial_value= 100., rebalancing_method = None):
